@@ -12,19 +12,17 @@ from .logging import logger
 
 @click.group()
 @common_options
-@click.pass_obj
-def cli(ctx, **kwargs):
+def cli(**kwargs):
     """
-    ssh client wrapper with OIDC-based authentication
+    SSH client wrapper with OIDC-based authentication
     """
     pass
 
 
 @cli.command(name="info", short_help="get info about service")
 @common_options
-@click.pass_obj
 @click.argument("hostname")
-def info(ctx, mc_endpoint, verify, token, oa_account, iss, hostname):
+def info(mc_endpoint, verify, token, oa_account, iss, hostname):
     """Get information about SSH service running on HOSTNAME:
     supported OIDC providers, service description and help.
 
@@ -38,8 +36,9 @@ def info(ctx, mc_endpoint, verify, token, oa_account, iss, hostname):
             mc_url = init_endpoint([hostname], verify)
         try:
             at, _ = init_token(token, oa_account, iss, mc_url, verify)
-        except Exception:
+        except Exception as e:
             at = None
+            logger.info(e)
             logger.warning("No access token found, will not show authorisation information")
         click.echo(str_info_all(mc_url, at, verify))
     except Exception as e:
@@ -52,7 +51,7 @@ def info(ctx, mc_endpoint, verify, token, oa_account, iss, hostname):
                  "allow_extra_args": True
              })
 @common_options
-@click.option("--dry-run", is_flag=True, help="print sshpass command and exit")
+@click.option("--dry-run", is_flag=True, help="Print sshpass command and exit.")
 @click.argument("ssh_command", nargs=-1, required=True, type=click.UNPROCESSED, callback=tuple_to_list)
 def ssh(mc_endpoint, verify, token, oa_account, iss, dry_run, ssh_command):
     """Connects and logs into HOSTNAME via SSH by using the provided OIDC
@@ -87,7 +86,7 @@ def ssh(mc_endpoint, verify, token, oa_account, iss, dry_run, ssh_command):
                  "allow_extra_args": True
              })
 @common_options
-@click.option("--dry-run", is_flag=True, help="print sshpass command and exit")
+@click.option("--dry-run", is_flag=True, help="Print sshpass command and exit.")
 @click.argument("scp_command", nargs=-1, required=True, type=click.UNPROCESSED, callback=tuple_to_list)
 def scp(mc_endpoint, verify, token, oa_account, iss, dry_run, scp_command):
     """Copies files between hosts on a network over SSH using the provided
